summaryrefslogtreecommitdiffstats
path: root/src/server/GraphObjectImpl.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/server/GraphObjectImpl.hpp')
-rw-r--r--src/server/GraphObjectImpl.hpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/server/GraphObjectImpl.hpp b/src/server/GraphObjectImpl.hpp
index 5388981f..07a59727 100644
--- a/src/server/GraphObjectImpl.hpp
+++ b/src/server/GraphObjectImpl.hpp
@@ -35,12 +35,12 @@ namespace Shared { class URIs; }
namespace Server {
-class PatchImpl;
+class BufferFactory;
class Context;
+class GraphImpl;
class ProcessContext;
-class BufferFactory;
-/** An object on the audio graph (a Patch, Block, or Port).
+/** An object on the audio graph (a Graph, Block, or Port).
*
* Each of these is a Raul::Deletable and so can be deleted in a realtime safe
* way from anywhere, and they all have a map of variable for clients to store
@@ -70,8 +70,8 @@ public:
const Raul::Atom& get_property(const Raul::URI& key) const;
- /** The Patch this object is a child of. */
- virtual PatchImpl* parent_patch() const;
+ /** The Graph this object is a child of. */
+ virtual GraphImpl* parent_graph() const;
const Raul::Path& path() const { return _path; }